bangdiwala.table: Bangdiwala B coefficient for 2 raters

View source: R/agree.coeff2.r

bangdiwala.tableR Documentation

Bangdiwala B coefficient for 2 raters

Description

Bangdiwala B coefficient for 2 raters

Usage

bangdiwala.table(ratings, conflev = 0.95, N = Inf)

Arguments

ratings

A square table of ratings (assume no missing ratings).

conflev

An optional parameter that specifies the confidence level used for constructing confidence intervals. By default the function assumes the standard value of 95%.

N

An optional parameter representing the finite population size if any. It is used to perform the finite population correction to the standard error. It's default value is infinity.

Value

A data frame containing the following 5 variables: coeff.name coeff.val coeff.se coeff.ci coeff.pval.

Examples

#The dataset "cont3x3abstractors" comes with this package. Analyze it as follows:
bangdiwala.table(cont3x3abstractors) #Yields Bangdiwala coefficient along with precision measures
Bcoeff <- bangdiwala.table(cont3x3abstractors)$coeff.val #Yields Bangdiwala's coefficient alone.
Bcoeff
q <- nrow(cont3x3abstractors) #Number of categories

irrCAC documentation built on April 27, 2026, 9:08 a.m.