identity.weights: Function for computing the Identity Weights

View source: R/weights.gen.r

identity.weightsR Documentation

Function for computing the Identity Weights

Description

Function for computing the Identity Weights

Usage

identity.weights(categ)

Arguments

categ

A mandatory parameter representing the vector of all possible ratings.

Value

A square matrix of identity weights to be used for calculating the unweighted coefficients.


irrCAC documentation built on April 27, 2026, 9:08 a.m.