landis.koch.bf: Computing Landis-Koch Benchmark Scale Membership...

View source: R/benchmarking.r

landis.koch.bfR Documentation

Computing Landis-Koch Benchmark Scale Membership Probabilities

Description

Computing Landis-Koch Benchmark Scale Membership Probabilities

Usage

landis.koch.bf(coeff, se, BenchDF = landis.koch)

Arguments

coeff

A mandatory parameter representing the estimated value of an agreement coefficient.

se

A mandatory parameter representing the agreement coefficient standard error.

BenchDF

An optional parameter that is a 3-column data frame containing the Landis & Koch's benchmark scale information. The 3 columns are the interval lower bound, upper bound, and their interpretation. The default value is a small file contained in the package and named landis.koch.RData, which describes the official Landis & Koch's scale intervals and their interpretation.

Value

A one-column matrix containing the membership probabilities (c.f. https://agreestat.com/papers/inter-rater%20reliability%20study%20design1.pdf)


irrCAC documentation built on April 27, 2026, 9:08 a.m.