linear.weights: Function for computing the Linear Weights

View source: R/weights.gen.r

linear.weightsR Documentation

Function for computing the Linear Weights

Description

Function for computing the Linear Weights

Usage

linear.weights(categ)

Arguments

categ

A mandatory parameter representing the vector of all possible ratings.

Value

A square matrix of quadratic weights to be used for calculating the weighted coefficients.


irrCAC documentation built on April 27, 2026, 9:08 a.m.