ordinal.weights: Function for computing the Ordinal Weights

View source: R/weights.gen.r

ordinal.weightsR Documentation

Function for computing the Ordinal Weights

Description

Function for computing the Ordinal Weights

Usage

ordinal.weights(categ)

Arguments

categ

A mandatory parameter representing the vector of all possible ratings.

Value

A square matrix of quadratic weights to be used for calculating the weighted coefficients.


irrCAC documentation built on April 27, 2026, 9:08 a.m.