| bangdiwala.table | R Documentation |
Bangdiwala B coefficient for 2 raters
bangdiwala.table(ratings, conflev = 0.95, N = Inf)
ratings |
A square table of ratings (assume no missing ratings). |
conflev |
An optional parameter that specifies the confidence level used for constructing confidence intervals. By default the function assumes the standard value of 95%. |
N |
An optional parameter representing the finite population size if any. It is used to perform the finite population correction to the standard error. It's default value is infinity. |
A data frame containing the following 5 variables: coeff.name coeff.val coeff.se coeff.ci coeff.pval.
#The dataset "cont3x3abstractors" comes with this package. Analyze it as follows:
bangdiwala.table(cont3x3abstractors) #Yields Bangdiwala coefficient along with precision measures
Bcoeff <- bangdiwala.table(cont3x3abstractors)$coeff.val #Yields Bangdiwala's coefficient alone.
Bcoeff
q <- nrow(cont3x3abstractors) #Number of categories
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.